{% load i18n cosinnus_tags widget_tweaks %}

{# sadly we have no practical way of a block to extend for this #}
{% include 'cosinnus/common/simplemde_dependencies.html' with element_id=form.forms.obj.text.id_for_label %}

{% captureas label %}
    {% if user|can_create_objects_in:group %}
        
        {% include 'cosinnus_note/note_form_core.html' %}
        
    {% else %}
        <div>
            <p>
                {% trans "To post in this team you need to" %}
                <a href="#" data-toggle="modal" data-target="#join_withdraw_modal">
                    <i class="fa fa-sign-out"></i>
                    <span>{% trans "request to join" %}</span></a>!
            </p>
        </div>
    {% endif %}
{% endcaptureas %}


{% captureas title %}{% trans "Write a news post" %}{% endcaptureas %}
{% trans "Cancel" as cancel_button_label %}
{% captureas submit_button_label %}{% trans "Post" %}{% endcaptureas %}
{% captureas action %}{% group_url 'cosinnus:note:add' group=group %}{% endcaptureas %}
{% include "cosinnus/modal_box.html" with id="write-news-modal" label=label form_action=action title=title title_icon="fa-write" extra_modal_classes="modal-lg" %}
