{% load i18n cosinnus_tags %}

{% with note=object %}
    <div class="app-main">
        <div class="btn btn-emphasized w100">
            <ul class="media-list large-space">
                <li class="media">
                    <a class="pull-left" href="#">
                        <i class="fa fa-book"></i>
                    </a>
                    <div class="media-body no-vertical-padding">
                        <span class="annotation">
                            {% with creator=note.creator %}
                                {# {% trans "by" %} #} <strong><a href="{{ creator|profile_url }}" >{{ creator|full_name }}</a></strong> 
                            {% endwith %}
                            <span class="moment-data-date" data-date="{{ note.created|date:'c' }}" title="{{ note.created|date:'r' }}"></span>
                        </span>
                        <strong><a href="{{ note.get_absolute_url }}">{% if note.title and not note.title == '---' %}{{ note.title }}{% endif %}{{ note.text }}</a></strong>
                        <div class="group-annotation">
                            {% include 'cosinnus/group/group_label.html' with group=note.group %}
                        </div>
                    </div>
                </li>
            </ul>
        </div><!-- btn -->
    </div>
{% endwith %}
